# coding: utf-8

"""
    MoneyKit API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2023-02-18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class SecurityResponse(BaseModel):
    """
    SecurityResponse
    """  # noqa: E501

    id: StrictStr = Field(description="A unique MoneyKit ID for this security.")
    name: StrictStr = Field(description="A user-facing name for this security.")
    type: StrictStr = Field(
        description="The type of this security.  Will be one of: <p>`cash`: Cash, currency, and money market funds <p>`crypto`: Digital or virtual currencies <p>`derivative`: Options, warrants, and other derivative instruments <p>`equity`: Equities (stocks) <p>`etf`: Exchange-traded investment funds <p>`bond`: Bonds and certificates of deposit (CDs) <p>`loan`: Loans and loan receivables <p>`fund`: Open- and closed-end vehicles pooling funds of multiple investors <p>`unknown`: Indicates the type is unknown or does not fit into any other category"
    )
    currency: StrictStr = Field(
        description="The ISO-4217 code for the currency in which this security is priced."
    )
    ticker: Optional[StrictStr] = Field(
        default=None, description="The security's public trading symbol, if available."
    )
    isin: Optional[StrictStr] = Field(
        default=None,
        description="The ISO 6166 globally unique ID for this security, if available.",
    )
    sedol: Optional[StrictStr] = Field(
        default=None,
        description="The security's SEDOL ID from the London Stock Exchange, if available.",
    )
    close_price: Optional[StrictStr] = Field(
        default=None,
        description="The price of the security at the close of the previous trading session, given in pricing currency.",
    )
    close_date: Optional[date] = Field(
        default=None, description="The date for which `close_price` is given."
    )
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "type",
        "currency",
        "ticker",
        "isin",
        "sedol",
        "close_price",
        "close_date",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SecurityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of SecurityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "type": obj.get("type"),
                "currency": obj.get("currency"),
                "ticker": obj.get("ticker"),
                "isin": obj.get("isin"),
                "sedol": obj.get("sedol"),
                "close_price": obj.get("close_price"),
                "close_date": obj.get("close_date"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj
